@@ -16,6 +16,7 @@ from .constants import (
     _contract_addresses_oracle
 )
 
+
 def _str_to_addr(s: Union[AddressLike, str]) -> Address:
     """Idempotent"""
     try:
@@ -24,8 +25,8 @@ def _str_to_addr(s: Union[AddressLike, str]) -> Address:
                 return Address(bytes.fromhex(s[2:]))
     except:
         raise InvalidFormatError(
-            StatusCode.BAD_REQUEST.value, 
-            StatusCode.UKNOWN_ADDRESS.value, 
+            StatusCode.BAD_REQUEST.value,
+            StatusCode.UKNOWN_ADDRESS.value,
             ErrorMessage.INVALID_ADDRESS_FORMAT.value)
 
 
@@ -39,9 +40,9 @@ def _addr_to_str(a: AddressLike) -> str:
         return addr
 
     raise InvalidFormatError(
-                StatusCode.BAD_REQUEST.value, 
-                StatusCode.UKNOWN_ADDRESS.value, 
-                ErrorMessage.INVALID_ADDRESS_FORMAT.value)
+        StatusCode.BAD_REQUEST.value,
+        StatusCode.UKNOWN_ADDRESS.value,
+        ErrorMessage.INVALID_ADDRESS_FORMAT.value)
 
 
 def is_same_address(a1: Union[AddressLike, str], a2: Union[AddressLike, str]) -> bool:
@@ -57,8 +58,12 @@ def _load_abi(name: str, network: str) -> str:
     with open(os.path.abspath(path + network + f".json")) as f:
         meta = json.load(f)
         abi = meta["contracts"][name]["abi"]
+
+    if name == 'Manager':
+        print('abi-manager', abi)
     return abi
 
+
 def _load_oracle_abi() -> str:
     path = f"{os.path.dirname(os.path.abspath(__file__))}/assets/"
     with open(os.path.abspath(path + f"AggregatorV3InterfaceABI.json")) as f:
@@ -68,9 +73,10 @@ def _load_oracle_abi() -> str:
 
 
 @functools.lru_cache()
-def _load_contract(w3: Web3,  network: str, abi_name: str, address: AddressLike) -> Contract:
+def _load_contract(w3: Web3,  network: str, abi_name: str, address: AddressLike, abi: str) -> Contract:
     address = Web3.toChecksumAddress(address)
-    return w3.eth.contract(address=address, abi=_load_abi(abi_name, network))
+    return w3.eth.contract(address=address, abi=abi)
+
 
 @functools.lru_cache()
 def _load_oracle_contract(w3: Web3, address: AddressLike) -> Contract:
@@ -81,6 +87,7 @@ def _load_oracle_contract(w3: Web3, address: AddressLike) -> Contract:
 def _load_contract_erc20(w3: Web3, address: AddressLike) -> Contract:
     return _load_contract(w3, "erc20", address)
 
+
 def _side_str_to_int(side: str) -> Any:
     try:
         if side.lower() == 'buy':
@@ -88,53 +95,70 @@ def _side_str_to_int(side: str) -> Any:
         elif side.lower() == 'sell':
             return 1
         else:
-            raise InvalidParameterError(StatusCode.BAD_REQUEST.value, StatusCode.UNKNOWN_SIDE.value, ErrorMessage.INVALID_SIDE.value %side)
+            raise InvalidParameterError(
+                StatusCode.BAD_REQUEST.value, StatusCode.UNKNOWN_SIDE.value, ErrorMessage.INVALID_SIDE.value % side)
     except:
-        raise InvalidParameterError(StatusCode.BAD_REQUEST.value, StatusCode.UNKNOWN_SIDE.value, ErrorMessage.INVALID_SIDE.value %side)
+        raise InvalidParameterError(
+            StatusCode.BAD_REQUEST.value, StatusCode.UNKNOWN_SIDE.value, ErrorMessage.INVALID_SIDE.value % side)
+
 
 def _amm_name_to_addr(amm: str, network: str) -> Any:
     try:
         amm_title = "Amm_" + amm.lower()
-        return Web3.toChecksumAddress(_contract_addresses_proxy_v1[network][amm_title])
+        return Web3.toChecksumAddress(_contract_addresses_proxy_v1[amm_title])
     except:
-        raise InvalidParameterError(StatusCode.BAD_REQUEST.value, StatusCode.UKNOWN_ADDRESS.value, ErrorMessage.INVALID_MARKET.value %amm)
+        raise InvalidParameterError(
+            StatusCode.BAD_REQUEST.value, StatusCode.UKNOWN_ADDRESS.value, ErrorMessage.INVALID_MARKET.value % amm)
+
 
 def _amm_name_to_oracle_addr(amm: str, network: str) -> Any:
     try:
         amm_title = amm.lower()
         return _contract_addresses_oracle[network][amm_title]
     except:
-        raise InvalidParameterError(StatusCode.BAD_REQUEST.value, StatusCode.UKNOWN_ADDRESS.value, ErrorMessage.INVALID_MARKET.value %amm)
+        raise InvalidParameterError(
+            StatusCode.BAD_REQUEST.value, StatusCode.UKNOWN_ADDRESS.value, ErrorMessage.INVALID_MARKET.value % amm)
+
 
 def _int_to_bignum(num):
     if isinstance(num, int) or isinstance(num, float):
         return int(num*(10**18))
     else:
-        raise InvalidParameterError(StatusCode.BAD_REQUEST.value, StatusCode.UNKNOWN_AMOUNT.value, ErrorMessage.INVALID_AMOUNT.value)
+        raise InvalidParameterError(
+            StatusCode.BAD_REQUEST.value, StatusCode.UNKNOWN_AMOUNT.value, ErrorMessage.INVALID_AMOUNT.value)
+
 
 def _check_leverage(leverage: int):
     if (leverage < 1 or leverage > 10) or (not isinstance(leverage, int)) or (not leverage % 1 == 0):
-        raise InvalidParameterError(StatusCode.BAD_REQUEST.value, StatusCode.INVALID_LEVERAGE.value, ErrorMessage.INVALID_LEVERAGE_VALUE.value)
+        raise InvalidParameterError(
+            StatusCode.BAD_REQUEST.value, StatusCode.INVALID_LEVERAGE.value, ErrorMessage.INVALID_LEVERAGE_VALUE.value)
     else:
         pass
 
+
 def _check_slippage(slippage):
     if not (isinstance(slippage, int) or isinstance(slippage, float)):
-        raise InvalidParameterError(StatusCode.BAD_REQUEST.value, StatusCode.INVALID_SLIPPAGE.value, ErrorMessage.INVALID_ARG_TYPE.value%"slippage")
+        raise InvalidParameterError(
+            StatusCode.BAD_REQUEST.value, StatusCode.INVALID_SLIPPAGE.value, ErrorMessage.INVALID_ARG_TYPE.value % "slippage")
     if (slippage < 0 or slippage > 0.05):
-        raise InvalidParameterError(StatusCode.BAD_REQUEST.value, StatusCode.INVALID_SLIPPAGE.value, ErrorMessage.SLIPPAGE_LIMIT_EXCEEDED.value)
+        raise InvalidParameterError(
+            StatusCode.BAD_REQUEST.value, StatusCode.INVALID_SLIPPAGE.value, ErrorMessage.SLIPPAGE_LIMIT_EXCEEDED.value)
     else:
         pass
 
+
 def _check_collateral(quoteAssetAmount: int):
     if quoteAssetAmount == 0:
-        raise InvalidParameterError(StatusCode.BAD_REQUEST.value, StatusCode.ZERO_COLLATERAL.value, ErrorMessage.ZERO_COLLATERAL.value)
+        raise InvalidParameterError(
+            StatusCode.BAD_REQUEST.value, StatusCode.ZERO_COLLATERAL.value, ErrorMessage.ZERO_COLLATERAL.value)
     else:
         pass
 
+
 def _normalize(amount: int):
     return round(amount/10**18, 7)
 
+
 def _estimate_gas_fee(_type: str, _network: str):
     try:
         _url = None
@@ -145,9 +169,11 @@ def _estimate_gas_fee(_type: str, _network: str):
         res = requests.get(_url).json()
         return _validate_station_res(res, _type)
     except:
-        raise TransactionFailedError(StatusCode.FAILED_TRANSACTION.value, StatusCode.CANNOT_FETCH_GAS_FEES.value, ErrorMessage.CANNOT_FETCH_GAS_FEES.value)
+        raise TransactionFailedError(StatusCode.FAILED_TRANSACTION.value,
+                                     StatusCode.CANNOT_FETCH_GAS_FEES.value, ErrorMessage.CANNOT_FETCH_GAS_FEES.value)
+
 
 def _validate_station_res(res, _type):
     if res[_type]['maxPriorityFee'] > res[_type]['maxFee']:
         res[_type]['maxFee'] = res['maxPriorityFee'] + res['estimatedBaseFee']
-    return res[_type]
\ No newline at end of file
+    return res[_type]
